@@ -404,6 +404,7 @@ interact(int *ok)
 	    "'x'           reset and reboot machine\n"
 #ifdef HIDDEN_COMMAND
 	    "'d'           toggle debug mode\n"
+	    "'L'           toggle LARGE READ MODE disk_2gb_limit\n"
 #endif
 	    "? ");
 	numbuf[0] = '0';
@@ -462,6 +463,14 @@ interact(int *ok)
 	    continue;
 	}
 
+	if (numbuf[0] == 'L') /* hidden option! */
+	{
+	    join(commandline, argc, argv, ok);
+	    disk_2gb_limit = !disk_2gb_limit;
+	    printf("disk_2gb_limit is now %s\n", disk_2gb_limit ? "on":"off");
+	    continue;
+	}
+
 
 	editfield = parse_number(numbuf, &p);
 
@@ -556,7 +565,7 @@ iplmain(int is_interactive, char *initialstackptr, int started_wide)
     }
 
     disk_2gb_limit = pdc_bootdisk_2GB_limit();
-    printf("Boot limited to sectors below 2GB: %s\n", disk_2gb_limit ? "YES":"NO");
+    printf("Booting from media >2GB possible: %s\n", disk_2gb_limit ? "NO":"YES");
 
  restart:
 
@@ -888,7 +897,7 @@ iplmain(int is_interactive, char *initialstackptr, int started_wide)
 	    goto restart;
     printf("Branching to kernel entry point 0x%08x. If this is the last message you\n"
 	   "see, you may need to switch your console. This is a common symptom -- search\n"
-	   "the FAQ and mailing list at https://parisc.wiki.kernel.org\n\n",
+	   "the FAQ and mailing list at https://parisc.docs.kernel.org\n\n",
 	   entry);
     return entry;
 }
