@@ -38,6 +38,8 @@
 static int Install = 0;
 int verbose = 0;
 
+int disk_2gb_limit = 0;
+
 /* compute the sum of words in an 4-byte aligned region */
 int
 checksum(void *p, size_t len)
@@ -757,7 +759,7 @@ main(int argc, char *argv[])
 	assert((unsigned long)&f.ipl_addr - (unsigned long)&f == 0xf0);
     }
 
-    fputs("palo - boot media management tool for PA-RISC/HPPA.\n", stdout);
+    fputs("palo " PALOVERSION " - boot media management tool for PA-RISC/HPPA.\n", stdout);
 
     /* do we have a -f? */
     while ((c = GETOPT(argc, argv, gargs)) != EOF)
